@@ -1,7 +1,9 @@
-__version__ = "0.2.3"
+__version__ = "0.2.10"
 from .logger import DAGsHubLogger, dagshub_logger
+from .common.init import init
 
 __all__ = [
     DAGsHubLogger,
     dagshub_logger,
+    init
 ]
